@@ -2,12 +2,11 @@ try:
     from bae.api import logging
 except:
     import logging
-    #from httpc import #logger
     def init_logging(set_level = logging.INFO, 
                  console = True,
                  log_file_path = None):
-        common.init_logging(httpc.#logger, set_level, console, log_file_path)
-    
+        pass
+ 
 from bcs import BCS
 from bucket import Bucket
 
