@@ -19,11 +19,7 @@ try:
 except:
     import simplejson as json
 
-try:
-    from bae.api import logging as #logger
-except:
-    import logging
-    #logger = logging.getLogger('pyhttpclient')
+import logging
 
 from cStringIO import StringIO
 from urlparse import urlparse
@@ -168,7 +164,7 @@ class PyCurlHTTPC(HTTPC):
 
     def post(self, url, body='', headers={}, log=True):
         headers = copy.deepcopy(headers)
-        if log: 
+        #if log: 
             #logger.info('pycurl -X POST "%s" ', url)
         headersnew = { 'Content-Length': str(len(body))}
         headers.update(headersnew)
@@ -279,12 +275,6 @@ class PyCurlHTTPC(HTTPC):
                         pycurl.INFOTYPE_SSL_DATA_IN]        #5
         curl_info = [   pycurl.INFOTYPE_TEXT]               #0 
 
-        if debug_type in curl_out:
-            #logger.debug("> %s" % debug_msg.strip())
-        elif debug_type in curl_in:
-            #logger.debug("< %s" % debug_msg.strip())
-        else:
-            #logger.debug("I %s" % (debug_msg.strip()) )
 
 
 class HttplibHTTPC(HTTPC):
@@ -299,7 +289,7 @@ class HttplibHTTPC(HTTPC):
             resp_body = ''
         else:
             resp_body = response.read()
-        for (k, v) in response.getheaders():
+        #for (k, v) in response.getheaders():
             #logger.debug('< %s: %s' % (k, v))
         #logger.debug('< ' + shorten(data, 1024))
         rst = { 'status': response.status, 
@@ -315,7 +305,7 @@ class HttplibHTTPC(HTTPC):
     #used by all 
     def send_request(self, verb, url, data, headers={}):
         #logger.info('ll httplibcurl -X "%s" "%s" ', verb, url)
-        for (k, v) in headers.items():
+        #for (k, v) in headers.items():
             #logger.debug('> %s: %s' % (k, v))
         #logger.debug('\n')
         #logger.debug('> ' + shorten(data, 1024))
